@@ -178,6 +178,7 @@ sub find_openssl_prefix {
     }
 
     my @guesses = (
+	'/home/linuxbrew/.linuxbrew/opt/openssl/bin/openssl' => '/home/linuxbrew/.linuxbrew/opt/openssl', # LinuxBrew openssl
 	'/usr/local/opt/openssl/bin/openssl' => '/usr/local/opt/openssl', # OSX homebrew openssl
 	'/usr/local/bin/openssl'         => '/usr/local', # OSX homebrew openssl
 	'/opt/local/bin/openssl'         => '/opt/local', # Macports openssl
@@ -230,7 +231,7 @@ sub check_openssl_version {
 
     {
         my $pipe = gensym();
-        open($pipe, "$exec version |")
+        open($pipe, qq{"$exec" version |})
             or die "Could not execute $exec";
         my $output = <$pipe>;
         chomp $output;
@@ -258,7 +259,7 @@ EOM
         exit 0; # according http://wiki.cpantesters.org/wiki/CPANAuthorNotes this is best-practice when "missing library"
     }
 
-    if ($major > 1.0 || ($major == 1.0 && $minor > 2)) {
+    if ($major == 1.1 && $minor > 0) {
         print <<EOM;
 *** That's newer than what this module was tested with
     You should consider checking if there is a newer release of this module
